==> ejudge-2.3.26.tgz: ejudge/checkers/cmp_file.c <==
/* -*- mode: c -*- */
/* $Id: cmp_file.c 7036 2012-09-25 08:41:24Z cher $ */

/* Copyright (C) 2004-2012 Alexander Chernov <cher@ejudge.ru> */

/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#define NEED_CORR 1
#define NEED_INFO 0
#define NEED_TGZ  0
#include "checker.h"

int checker_main(int argc, char **argv)
{
  char **out_lines, **corr_lines;
  size_t out_lines_num, corr_lines_num, i;
  int nocase = 0;

  if (getenv("EJ_REQUIRE_NL")) {
    if (fseek(f_out, -1L, SEEK_END) >= 0) {
      if (getc(f_out) != '\n') fatal_PE("no final \\n in the output file");
      fseek(f_out, 0L, SEEK_SET);
    }
  }

  //     
  checker_read_file_by_line(1, &out_lines, &out_lines_num);
  //   
  checker_read_file_by_line(2, &corr_lines, &corr_lines_num);
  //      
  checker_normalize_file(out_lines, &out_lines_num);
  //     
  checker_normalize_file(corr_lines, &corr_lines_num);
  if (getenv("EJUDGE_NOCASE")) nocase = 1;

  if (out_lines_num != corr_lines_num)
    fatal_WA("Different number of lines: out = %zu, corr = %zu",
             out_lines_num, corr_lines_num);
  for (i = 0; i < out_lines_num; i++)
    if (nocase) {
      if (strcasecmp(out_lines[i], corr_lines[i]) != 0)
        fatal_WA("Line %zu differs: out:\n>%s<\ncorr:\n>%s<",
                 i + 1, out_lines[i], corr_lines[i]);
    } else {
      if (strcmp(out_lines[i], corr_lines[i]) != 0)
        fatal_WA("Line %zu differs: out:\n>%s<\ncorr:\n>%s<",
                 i + 1, out_lines[i], corr_lines[i]);
    }
  
  checker_OK();
}

/*
 * Local variables:
 *  compile-command: "gcc -Wall -O2 -s -I. -L. cmp_file.c -ocmp_file -lchecker"
 *  c-font-lock-extra-types: ("\\sw+_t" "FILE")
 * End:
 */

==> ejudge-2.3.28.1.tgz: ejudge/checkers/cmp_file.c <==
/* -*- mode: c -*- */
/* $Id: cmp_file.c 7460 2013-10-21 21:35:57Z cher $ */

/* Copyright (C) 2004-2013 Alexander Chernov <cher@ejudge.ru> */

/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#define NEED_CORR 1
#define NEED_INFO 0
#define NEED_TGZ  0
#include "checker.h"

#include "l10n_impl.h"

int checker_main(int argc, char **argv)
{
  char **out_lines, **corr_lines;
  size_t out_lines_num, corr_lines_num, i;
  int nocase = 0;

  checker_l10n_prepare();

  if (getenv("EJ_REQUIRE_NL")) {
    if (fseek(f_out, -1L, SEEK_END) >= 0) {
      if (getc(f_out) != '\n') fatal_PE(_("No final \\n in the output file"));
      fseek(f_out, 0L, SEEK_SET);
    }
  }

  // считываем файл результата работы программы
  checker_read_file_by_line(1, &out_lines, &out_lines_num);
  // считываем эталонный файл
  checker_read_file_by_line(2, &corr_lines, &corr_lines_num);
  // отбрасываем пробелы в результате работы программы
  checker_normalize_file(out_lines, &out_lines_num);
  // отбрасываем пробелы в эталонном файле
  checker_normalize_file(corr_lines, &corr_lines_num);
  if (getenv("EJUDGE_NOCASE")) nocase = 1;

  if (out_lines_num != corr_lines_num)
    fatal_WA(_("Different number of lines: output: %zu, correct: %zu"),
             out_lines_num, corr_lines_num);
  for (i = 0; i < out_lines_num; i++)
    if (nocase) {
      if (strcasecmp(out_lines[i], corr_lines[i]) != 0)
        fatal_WA(_("Line %zu differs: output:\n>%s<\ncorrect:\n>%s<"),
                 i + 1, out_lines[i], corr_lines[i]);
    } else {
      if (strcmp(out_lines[i], corr_lines[i]) != 0)
        fatal_WA(_("Line %zu differs: output:\n>%s<\ncorrect:\n>%s<"),
                 i + 1, out_lines[i], corr_lines[i]);
    }
  
  checker_OK();
}
